@@ -27,7 +27,12 @@ import {
 } from '@tamanu/shared/utils/crudHelpers';
 import { add } from 'date-fns';
 import { z } from 'zod';
-import { deleteChartInstance, fetchAnswersWithHistory, fetchGraphData, fetchChartInstances } from '../../routeHandlers/charts';
+import {
+  deleteChartInstance,
+  fetchAnswersWithHistory,
+  fetchGraphData,
+  fetchChartInstances,
+} from '../../routeHandlers/charts';
 import { keyBy } from 'lodash';
 
 import { createEncounterSchema } from '@tamanu/shared/schemas/facility/requests/createEncounter.schema';
@@ -206,11 +211,30 @@ encounter.post(
     const { id } = params;
     req.checkPermission('write', 'Encounter');
     req.checkPermission('read', 'Medication');
+    req.checkPermission('create', 'MedicationRequest');
     const encounterObject = await models.Encounter.findByPk(id);
     if (!encounterObject) throw new NotFoundError();
 
-    const { orderingClinicianId, comments, isDischargePrescription, pharmacyOrderPrescriptions } =
-      body;
+    const {
+      orderingClinicianId,
+      comments,
+      isDischargePrescription,
+      pharmacyOrderPrescriptions,
+      facilityId,
+    } = body;
+
+    const prescriptionRecords = await models.Prescription.findAll({
+      where: { id: pharmacyOrderPrescriptions.map(p => p.prescriptionId) },
+      attributes: ['id', 'medicationId', 'quantity'],
+    });
+
+    const hasSensitive = await models.ReferenceDrug.hasSensitiveMedication(
+      prescriptionRecords.map(p => p.medicationId),
+    );
+
+    if (hasSensitive) {
+      req.checkPermission('read', 'SensitiveMedication');
+    }
 
     const result = await db.transaction(async () => {
       const pharmacyOrder = await models.PharmacyOrder.create({
@@ -218,6 +242,8 @@ encounter.post(
         encounterId: id,
         comments,
         isDischargePrescription,
+        date: getCurrentDateTimeString(),
+        facilityId,
       });
 
       await models.PharmacyOrderPrescription.bulkCreate(
@@ -392,19 +418,23 @@ encounterRelations.get(
     let responseData = prescriptions.map(p => p.forResponse());
     if (responseData.length > 0) {
       const prescriptionIds = responseData.map(p => p.id);
-      const [pharmacyOrderPrescriptions] = await db.query(
+      const [lastOrderedRows] = await db.query(
         `
-        SELECT prescription_id, max(created_at) as last_ordered_at
-        FROM pharmacy_order_prescriptions
-        WHERE prescription_id IN (:prescriptionIds) and deleted_at is null GROUP BY prescription_id
+        SELECT pop.prescription_id, max(po.date) AS last_ordered_at
+        FROM pharmacy_order_prescriptions pop
+        INNER JOIN pharmacy_orders po ON po.id = pop.pharmacy_order_id
+        WHERE pop.prescription_id IN (:prescriptionIds)
+          AND pop.deleted_at IS NULL
+          AND po.deleted_at IS NULL
+        GROUP BY pop.prescription_id
       `,
         { replacements: { prescriptionIds } },
       );
-      const lastOrderedAts = keyBy(pharmacyOrderPrescriptions, 'prescription_id');
+      const lastOrderedAts = keyBy(lastOrderedRows, 'prescription_id');
 
       responseData = responseData.map(p => ({
         ...p,
-        lastOrderedAt: lastOrderedAts[p.id]?.last_ordered_at?.toISOString(),
+        lastOrderedAt: lastOrderedAts[p.id]?.last_ordered_at,
       }));
     }
 
@@ -689,7 +719,7 @@ encounterRelations.get(
   fetchGraphData({
     permissionAction: 'read',
     permissionNoun: 'Charting',
-    dateDataElementId: CHARTING_DATA_ELEMENT_IDS.dateRecorded
+    dateDataElementId: CHARTING_DATA_ELEMENT_IDS.dateRecorded,
   }),
 );
 
@@ -777,9 +807,6 @@ encounterRelations.get(
   }),
 );
 
-encounterRelations.delete(
-  '/:id/chartInstances/:chartInstanceResponseId',
-  deleteChartInstance(),
-);
+encounterRelations.delete('/:id/chartInstances/:chartInstanceResponseId', deleteChartInstance());
 
 encounter.use(encounterRelations);
