@@ -185,11 +185,6 @@ export const globalSettings = {
           type: yup.boolean(),
           defaultValue: true,
         },
-        enableCovidClearanceCertificate: {
-          description: 'Enable COVID certificate printout',
-          type: yup.boolean(),
-          defaultValue: false,
-        },
         editPatientDisplayId: {
           description: 'Allow the editing of an existing patients display id',
           type: yup.boolean(),
@@ -340,7 +335,7 @@ export const globalSettings = {
             enabled: {
               description: 'Enable pharmacy orders',
               type: yup.boolean(),
-              defaultValue: false,
+              defaultValue: true,
             },
             medicationAlreadyOrderedConfirmationTimeout: {
               description:
@@ -349,6 +344,11 @@ export const globalSettings = {
               defaultValue: 24,
               unit: 'hours',
             },
+            sendViaMSupply: {
+              description: 'Send pharmacy orders to mSupply (when an integration is configured)',
+              type: yup.boolean(),
+              defaultValue: false,
+            },
           },
         },
         useGlobalPdfFont: {
@@ -366,6 +366,33 @@ export const globalSettings = {
             },
           },
         },
+        labRequest: {
+          description: 'Lab request settings',
+          properties: {
+            enableLabResultsPrintout: {
+              name: 'Lab results printout',
+              description:
+                'Enable lab results printout (print results button and interim report option)',
+              type: yup.boolean(),
+              defaultValue: true,
+            },
+          },
+        },
+        covidCertificates: {
+          description: 'COVID certificate settings',
+          properties: {
+            enableCovidClearanceCertificate: {
+              description: 'Enable COVID certificate printout',
+              type: yup.boolean(),
+              defaultValue: false,
+            },
+            enableCovidVaccinationCertificateSigning: {
+              description: 'Enable signing of COVID vaccination certificate',
+              type: yup.boolean(),
+              defaultValue: false,
+            },
+          },
+        },
       },
     },
     customisations: {
@@ -1199,6 +1226,13 @@ export const globalSettings = {
                 schedulingLocations: { properties: layoutModuleProperties },
               },
             },
+            medication: {
+              description: '_',
+              properties: {
+                medicationActive: { properties: layoutModuleProperties },
+                medicationDispensed: { properties: layoutModuleProperties },
+              },
+            },
             imaging: {
               description: '_',
               properties: {
@@ -1352,14 +1386,33 @@ export const globalSettings = {
         appointmentConfirmation: {
           description: 'The email sent to confirm an appointment',
           properties: {
-            subject: {
-              type: yup.string().trim().min(1),
-              defaultValue: 'Appointment confirmation',
+            locationBooking: {
+              description: 'The email template sent to confirm a location booking',
+              properties: {
+                subject: {
+                  type: yup.string().trim().min(1),
+                  defaultValue: 'Booking confirmation',
+                },
+                body: {
+                  type: yup.string().trim().min(1),
+                  defaultValue:
+                    'Hi $firstName$ $lastName$,\n\nThis is a confirmation that your booking has been scheduled at $facilityName$.\nDate: $startDate$\nTime: $startTime$\nLocation: $locationName$, $facilityName$$clinicianName$\n\nDo not respond to this email.',
+                },
+              },
             },
-            body: {
-              type: yup.string().trim().min(1),
-              defaultValue:
-                'Hi $firstName$ $lastName$,\n\n This is a confirmation that your appointment has been scheduled at $facilityName$.\nDate: $startDate$\nTime: $startTime$\nLocation: $locationName$, $facilityName$$clinicianName$\n\nDo not respond to this email.',
+            outpatientAppointment: {
+              description: 'The email template sent to confirm an outpatient appointment',
+              properties: {
+                subject: {
+                  type: yup.string().trim().min(1),
+                  defaultValue: 'Appointment confirmation',
+                },
+                body: {
+                  type: yup.string().trim().min(1),
+                  defaultValue:
+                    'Hi $firstName$ $lastName$,\n\nThis is a confirmation that your appointment has been scheduled at $facilityName$.\nDate: $startDate$\nTime: $startTime$\nLocation: $locationName$, $facilityName$$clinicianName$\n\nDo not respond to this email.',
+                },
+              },
             },
           },
         },
@@ -1519,9 +1572,48 @@ export const globalSettings = {
         },
       },
     },
+    patientPortal: {
+      description: 'Patient portal settings',
+      properties: {
+        baseUrl: {
+          description: 'The base URL of the patient portal',
+          type: yup.string().trim().url().nullable(),
+          defaultValue: null,
+        },
+      },
+    },
     medications: {
       description: 'Medication settings',
       properties: {
+        dispensing: {
+          description: 'Medication dispensing settings',
+          properties: {
+            prescriptionLabelSize: {
+              description: 'Prescription label size.',
+              properties: {
+                width: {
+                  description: 'Prescription label width.',
+                  type: yup.number().min(1),
+                  defaultValue: 80,
+                  unit: 'mm',
+                },
+                height: {
+                  description: 'Prescription label height.',
+                  type: yup.number().min(1),
+                  defaultValue: 40,
+                  unit: 'mm',
+                },
+              },
+            },
+            autoDeleteTimeframeHours: {
+              name: 'Autodelete medication request timeframe in hours',
+              description: 'Medication requests not dispensed after this timeframe will be automatically deleted.',
+              type: yup.number().integer().positive(),
+              defaultValue: 72,
+              unit: 'hours',
+            },
+          },
+        },
         frequenciesEnabled: {
           description: 'Enable medication frequencies',
           properties: {
